/*------------------------------------------------------------------------------

Beetle01 class Parameters

All parameters required by the model are held within the Parameters class.
Within the batch version, these are hard-coded, and must be set at compile time.

Author: Steve Palmer, University of Aberdeen

Last updated: 8 December 2011

------------------------------------------------------------------------------*/

//---------------------------------------------------------------------------

#ifndef ParametersH
#define ParametersH
//---------------------------------------------------------------------------

#define BATCH 0
#define DEBUG 0

// random number seed - set to 0 to use current time
#define SEED 99
class Parameters
{
private:
// Landscape size
	int XMAX; // max. X value (max 400)
	int YMAX; // max. Y value (max 100)
	int PIX; // pixel size - set so that YMAX*PIX ~= 200

// Control parameters
	int PREDGENS;   // no. of predator generations per run
	int TEMP_METHOD;  // Method for temporal vairation in carrying capacity:
// 0 = Poisson, 1 = normal
	int DISP_METHOD;  // Dispersal method:
// 0 = global random
// 1 = global in proportion to Kmean
// 2 = global in proportion to 1 - N/K
// 3 = global in proportion to 1/exp(N/K)
// 4 = global in proportion to exp((K-N)/K)/(1+exp((K-N)/K))
// 5 = nearest neighbour random (torus)
	int DISPLAYFREQ;    // display map refresh frequency
	int SUMMARYFREQ;    // generation summary file output frequency
	int SPATIALSUMMSTART;  // generation to start spatial summary data

// Landscape parameters
	double MU;  // mean carrying capacity
	double SDSPATIAL;  // spatial s.d. in carrying capacity
	int KMIN;  // minimum permitted carrying capacity
	double SDTEMP;  // temporal s.d. in carrying capacity

// Predator parameters
	int PRED_START;   // predator initial population
// set to approx. XMAX * YMAX * MU
	double PRED_LAMBDA; // predator intrinsic growth rate
	double PRED_B;      // predator competition coefficient
	double PRED_MORT;  // predator dispersal mortality rate
	double PRED_PMUT;  // predator mutation probability (z)

public:
	Parameters();
	Parameters(Parameters* p);
	int getXmax();
	int getYmax();
	int getPix();
	int getPredGen();
	int getTempMethod();
	int getDispMethod();
	int getDispFreq();
	int getSummaryFreq();
	int getSpatialSummStart();
	double getMU();
	double getSdSpatial();
	int getKmin();
	double getSdTemp();
	int getPredstart();
	double getPredLambda();
	double getPredB();
	double getPredMort();
	double getPredPmut();
	void setXmax(int maxX);
	void setYmax(int maxY);
	void setPix(int pixelSize);
	void setPredGen(int generations);
	void setTempMethod(int tempMeth);
	void setDispMethod(int dispersalmethod);
	void setDispFreq(int refreshFreq);
	void setSummaryFreq(int outputFrq);
	void setSpatialSummStart(int gen);
	void setMU(double mean);
	void setSdSpatial(double spatialSD);
	void setKmin(int minSD);
	void setSdTemp(double temporalSD);
	void setPredstart(int initialPop);
	void setPredLambda(double growthRate);
	void setPredB(double competitionCoeff);
	void setPredMort(double mortalityRate);
	void setPredPmut(double mutationProb);
};
#endif
