/*------------------------------------------------------------------------------

Beetle01 class PredPop

The population of haploid beetles is held within PredPop as two vectors of
pointers to Animal objects, one to adults and one to juveniles.
PredPop includes functions representing breeding and dispersal within the population,
plus house-keeping functions to initialise the population and to calculate
population-level demographic statistics.

Author: Steve Palmer, University of Aberdeen

Last updated: 7 December 2011

------------------------------------------------------------------------------*/

//---------------------------------------------------------------------------

#ifndef PredatorsH
#define PredatorsH
//---------------------------------------------------------------------------


#include <vector>
#include <math.h>
#include <stdlib.h>

#include "stocc.h"

#include "Parameters.h"
#include "Landscape.h"
#include "Animal.h"

//using namespace std;

struct PredStats {
  int n; int dispersers; int residents;
  double meanDisp; double sdDisp; double minDisp; double maxDisp;
  double meanPstopInt; double meanPstopSlope;
  double meanNsteps; int maxNsteps; // mean and max no. of steps taken by dispersers
};

//==============================================================================
class PredPop
{
public:
  PredPop(int,double,double,double);
  ~PredPop();
  void InitialisePreds(Landscape*);
  int Breed(Landscape*,double,int);
  void Disperse(Landscape*);
  PredStats GetStats(Landscape*);
  double get_lambda(void);
  double get_b(void);
  double get_dispMort(void);

private:
  int Nstart;
  double lambda;
  double b;
  double dispMort;

  vector <Animal*> Adults;
  vector <Animal*> Juvs;

};
//==============================================================================

#endif
